@@ -1,18 +1,28 @@
+// Copyright 2018 the Kurbo Authors
+// SPDX-License-Identifier: Apache-2.0 OR MIT
+
 //! Cubic Bézier segments.
 
-use std::ops::{Mul, Range};
+use alloc::vec;
+use alloc::vec::Vec;
+use core::ops::{Mul, Range};
 
 use crate::MAX_EXTREMA;
 use crate::{Line, QuadSpline, Vec2};
 use arrayvec::ArrayVec;
 
-use crate::common::solve_quadratic;
-use crate::common::GAUSS_LEGENDRE_COEFFS_9;
+use crate::common::{
+    solve_quadratic, solve_quartic, GAUSS_LEGENDRE_COEFFS_16_HALF, GAUSS_LEGENDRE_COEFFS_24_HALF,
+    GAUSS_LEGENDRE_COEFFS_8, GAUSS_LEGENDRE_COEFFS_8_HALF,
+};
 use crate::{
     Affine, Nearest, ParamCurve, ParamCurveArclen, ParamCurveArea, ParamCurveCurvature,
     ParamCurveDeriv, ParamCurveExtrema, ParamCurveNearest, PathEl, Point, QuadBez, Rect, Shape,
 };
 
+#[cfg(not(feature = "std"))]
+use crate::common::FloatFuncs;
+
 const MAX_SPLINE_SPLIT: usize = 100;
 
 /// A single cubic Bézier segment.
@@ -34,9 +44,18 @@ struct ToQuads {
     n: usize,
 }
 
+/// Classification result for cusp detection.
+#[derive(Debug)]
+pub enum CuspType {
+    /// Cusp is a loop.
+    Loop,
+    /// Cusp has two closely spaced inflection points.
+    DoubleInflection,
+}
+
 impl CubicBez {
     /// Create a new cubic Bézier segment.
-    #[inline]
+    #[inline(always)]
     pub fn new<P: Into<Point>>(p0: P, p1: P, p2: P, p3: P) -> CubicBez {
         CubicBez {
             p0: p0.into(),
@@ -142,9 +161,18 @@ impl CubicBez {
     /// Approximate a cubic with a single quadratic
     ///
     /// Returns a quadratic approximating the given cubic that maintains
-    /// endpoint tangents if that is within tolerance, or None otherwise.
+    /// endpoint tangents if that is within tolerance, or `None` otherwise.
     fn try_approx_quadratic(&self, accuracy: f64) -> Option<QuadBez> {
-        if let Some(q1) = Line::new(self.p0, self.p1).crossing_point(Line::new(self.p2, self.p3)) {
+        if let Some(q1) = Line::new(self.p0, self.p1)
+            .crossing_point(Line::new(self.p2, self.p3))
+            .or_else(|| {
+                // with 3 to 4 consecutive equal points (with no valid crossing_point),
+                // we can try to use the common point as the quadratic control point.
+                // This matches fonttools' cu2qu: https://github.com/fonttools/fonttools/pull/3904
+                (self.p1 == self.p2 && (self.p0 == self.p1 || self.p2 == self.p3))
+                    .then_some(self.p1)
+            })
+        {
             let c1 = self.p0.lerp(q1, 2.0 / 3.0);
             let c2 = self.p3.lerp(q1, 2.0 / 3.0);
             if !CubicBez::new(
@@ -215,7 +243,7 @@ impl CubicBez {
         let delta_2 = dt * dt;
         let delta_3 = dt * delta_2;
 
-        std::iter::from_fn(move || {
+        core::iter::from_fn(move || {
             // if storage exists, we use it exclusively
             if let Some(storage) = storage.as_mut() {
                 return storage.pop();
@@ -246,13 +274,13 @@ impl CubicBez {
         (a, b, c, d)
     }
 
+    /// Rust port of cu2qu [calc_cubic_points](https://github.com/fonttools/fonttools/blob/3b9a73ff8379ab49d3ce35aaaaf04b3a7d9d1655/Lib/fontTools/cu2qu/cu2qu.py#L63-L68)
     fn from_parameters(a: Vec2, b: Vec2, c: Vec2, d: Vec2) -> Self {
-        CubicBez::new(
-            d.to_point(),
-            d.to_point() + (c / 3.0),
-            d.to_point() + (c / 3.0) + (b + c) / 3.0,
-            d.to_point() + (c / 3.0) + (b + c) / 3.0 + a,
-        )
+        let p0 = d.to_point();
+        let p1 = c.div_exact(3.0).to_point() + d;
+        let p2 = (b + c).div_exact(3.0).to_point() + p1.to_vec2();
+        let p3 = (a + d + c + b).to_point();
+        CubicBez::new(p0, p1, p2, p3)
     }
 
     fn subdivide_3(&self) -> (CubicBez, CubicBez, CubicBez) {
@@ -262,13 +290,22 @@ impl CubicBez {
             self.p2.to_vec2(),
             self.p3.to_vec2(),
         );
-        let mid1 = ((8.0 * p0 + 12.0 * p1 + 6.0 * p2 + p3) / 27.0).to_point();
-        let deriv1 = (p3 + 3.0 * p2 - 4.0 * p0) / 27.0;
-        let mid2 = ((p0 + 6.0 * p1 + 12.0 * p2 + 8.0 * p3) / 27.0).to_point();
-        let deriv2 = (4.0 * p3 - 3.0 * p1 - p0) / 27.0;
+        // The original Python cu2qu code here does not use division operator to divide by 27 but
+        // instead uses multiplication by the reciprocal 1 / 27. We want to match it exactly
+        // to avoid any floating point differences, hence in this particular case we do not use div_exact.
+        // I could directly use the Vec2 Div trait (also implemented as multiplication by reciprocal)
+        // but I prefer to be explicit here.
+        // Source: https://github.com/fonttools/fonttools/blob/85c80be/Lib/fontTools/cu2qu/cu2qu.py#L215-L218
+        // See also: https://github.com/linebender/kurbo/issues/272
+        let one_27th = 27.0_f64.recip();
+        let mid1 = ((8.0 * p0 + 12.0 * p1 + 6.0 * p2 + p3) * one_27th).to_point();
+        let deriv1 = (p3 + 3.0 * p2 - 4.0 * p0) * one_27th;
+        let mid2 = ((p0 + 6.0 * p1 + 12.0 * p2 + 8.0 * p3) * one_27th).to_point();
+        let deriv2 = (4.0 * p3 - 3.0 * p1 - p0) * one_27th;
+
         let left = CubicBez::new(
             self.p0,
-            ((2.0 * p0 + p1) / 3.0).to_point(),
+            (2.0 * p0 + p1).div_exact(3.0).to_point(),
             mid1 - deriv1,
             mid1,
         );
@@ -276,13 +313,15 @@ impl CubicBez {
         let right = CubicBez::new(
             mid2,
             mid2 + deriv2,
-            ((p2 + 2.0 * p3) / 3.0).to_point(),
+            (p2 + 2.0 * p3).div_exact(3.0).to_point(),
             self.p3,
         );
         (left, mid, right)
     }
 
     /// Does this curve fit inside the given distance from the origin?
+    ///
+    /// Rust port of cu2qu [cubic_farthest_fit_inside](https://github.com/fonttools/fonttools/blob/3b9a73ff8379ab49d3ce35aaaaf04b3a7d9d1655/Lib/fontTools/cu2qu/cu2qu.py#L281)
     fn fit_inside(&self, distance: f64) -> bool {
         if self.p2.to_vec2().hypot() <= distance && self.p1.to_vec2().hypot() <= distance {
             return true;
@@ -300,15 +339,125 @@ impl CubicBez {
 
     /// Is this cubic Bezier curve finite?
     #[inline]
-    pub fn is_finite(&self) -> bool {
+    pub const fn is_finite(&self) -> bool {
         self.p0.is_finite() && self.p1.is_finite() && self.p2.is_finite() && self.p3.is_finite()
     }
 
     /// Is this cubic Bezier curve NaN?
     #[inline]
-    pub fn is_nan(&self) -> bool {
+    pub const fn is_nan(&self) -> bool {
         self.p0.is_nan() || self.p1.is_nan() || self.p2.is_nan() || self.p3.is_nan()
     }
+
+    /// Determine the inflection points.
+    ///
+    /// Return value is t parameter for the inflection points of the curve segment.
+    /// There are a maximum of two for a cubic Bézier.
+    ///
+    /// See <https://www.caffeineowl.com/graphics/2d/vectorial/cubic-inflexion.html>
+    /// for the theory.
+    pub fn inflections(&self) -> ArrayVec<f64, 2> {
+        let a = self.p1 - self.p0;
+        let b = (self.p2 - self.p1) - a;
+        let c = (self.p3 - self.p0) - 3. * (self.p2 - self.p1);
+        solve_quadratic(a.cross(b), a.cross(c), b.cross(c))
+            .iter()
+            .copied()
+            .filter(|t| *t >= 0.0 && *t <= 1.0)
+            .collect()
+    }
+
+    /// Find points on the curve where the tangent line passes through the
+    /// given point.
+    ///
+    /// Result is array of t values such that the tangent line from the curve
+    /// evaluated at that point goes through the argument point.
+    pub fn tangents_to_point(&self, p: Point) -> ArrayVec<f64, 4> {
+        let (a, b, c, d_orig) = self.parameters();
+        let d = d_orig - p.to_vec2();
+        // coefficients of x(t) \cross x'(t)
+        let c4 = b.cross(a);
+        let c3 = 2.0 * c.cross(a);
+        let c2 = c.cross(b) + 3.0 * d.cross(a);
+        let c1 = 2.0 * d.cross(b);
+        let c0 = d.cross(c);
+        solve_quartic(c0, c1, c2, c3, c4)
+            .iter()
+            .copied()
+            .filter(|t| *t >= 0.0 && *t <= 1.0)
+            .collect()
+    }
+
+    /// Preprocess a cubic Bézier to ease numerical robustness.
+    ///
+    /// If the cubic Bézier segment has zero or near-zero derivatives as an interior
+    /// cusp, perturb the control points to make curvature finite, avoiding
+    /// numerical robustness problems in offset and stroke.
+    pub(crate) fn regularize_cusp(&self, dimension: f64) -> CubicBez {
+        let mut c = *self;
+        // First step: if control point is too near the endpoint, nudge it away
+        // along the tangent.
+        if let Some(cusp_type) = self.detect_cusp(dimension) {
+            let d01 = c.p1 - c.p0;
+            let d01h = d01.hypot();
+            let d23 = c.p3 - c.p2;
+            let d23h = d23.hypot();
+            match cusp_type {
+                CuspType::Loop => {
+                    c.p1 += (dimension / d01h) * d01;
+                    c.p2 -= (dimension / d23h) * d23;
+                }
+                CuspType::DoubleInflection => {
+                    // Avoid making control distance smaller than dimension
+                    if d01h > 2.0 * dimension {
+                        c.p1 -= (dimension / d01h) * d01;
+                    }
+                    if d23h > 2.0 * dimension {
+                        c.p2 += (dimension / d23h) * d23;
+                    }
+                }
+            }
+        }
+        c
+    }
+
+    /// Detect whether there is a cusp.
+    ///
+    /// Return a cusp classification if there is a cusp with curvature greater than
+    /// the reciprocal of the given dimension.
+    fn detect_cusp(&self, dimension: f64) -> Option<CuspType> {
+        let d01 = self.p1 - self.p0;
+        let d02 = self.p2 - self.p0;
+        let d03 = self.p3 - self.p0;
+        let d12 = self.p2 - self.p1;
+        let d23 = self.p3 - self.p2;
+        let det_012 = d01.cross(d02);
+        let det_123 = d12.cross(d23);
+        let det_013 = d01.cross(d03);
+        let det_023 = d02.cross(d03);
+        if det_012 * det_123 > 0.0 && det_012 * det_013 < 0.0 && det_012 * det_023 < 0.0 {
+            let q = self.deriv();
+            // accuracy isn't used for quadratic nearest
+            let nearest = q.nearest(Point::ORIGIN, 1e-9);
+            // detect whether curvature at minimum derivative exceeds 1/dimension,
+            // without division.
+            let d = q.eval(nearest.t);
+            let d2 = q.deriv().eval(nearest.t);
+            let cross = d.to_vec2().cross(d2.to_vec2());
+            if nearest.distance_sq.powi(3) <= (cross * dimension).powi(2) {
+                let a = 3. * det_012 + det_023 - 2. * det_013;
+                let b = -3. * det_012 + det_013;
+                let c = det_012;
+                let d = b * b - 4. * a * c;
+                if d > 0.0 {
+                    return Some(CuspType::DoubleInflection);
+                } else {
+                    return Some(CuspType::Loop);
+                }
+            }
+        }
+        None
+    }
 }
 
 /// An iterator for cubic beziers.
@@ -318,7 +467,7 @@ pub struct CubicBezIter {
 }
 
 impl Shape for CubicBez {
-    type PathElementsIter = CubicBezIter;
+    type PathElementsIter<'iter> = CubicBezIter;
 
     #[inline]
     fn path_elements(&self, _tolerance: f64) -> CubicBezIter {
@@ -328,6 +477,7 @@ impl Shape for CubicBez {
         }
     }
 
+    #[inline(always)]
     fn area(&self) -> f64 {
         0.0
     }
@@ -337,6 +487,7 @@ impl Shape for CubicBez {
         self.arclen(accuracy)
     }
 
+    #[inline(always)]
     fn winding(&self, _pt: Point) -> i32 {
         0
     }
@@ -404,12 +555,12 @@ impl ParamCurve for CubicBez {
         )
     }
 
-    #[inline]
+    #[inline(always)]
     fn start(&self) -> Point {
         self.p0
     }
 
-    #[inline]
+    #[inline(always)]
     fn end(&self) -> Point {
         self.p3
     }
@@ -428,46 +579,65 @@ impl ParamCurveDeriv for CubicBez {
     }
 }
 
+fn arclen_quadrature_core(coeffs: &[(f64, f64)], dm: Vec2, dm1: Vec2, dm2: Vec2) -> f64 {
+    coeffs
+        .iter()
+        .map(|&(wi, xi)| {
+            let d = dm + dm2 * (xi * xi);
+            let dpx = (d + dm1 * xi).hypot();
+            let dmx = (d - dm1 * xi).hypot();
+            (2.25f64.sqrt() * wi) * (dpx + dmx)
+        })
+        .sum::<f64>()
+}
+
+fn arclen_rec(c: &CubicBez, accuracy: f64, depth: usize) -> f64 {
+    let d03 = c.p3 - c.p0;
+    let d01 = c.p1 - c.p0;
+    let d12 = c.p2 - c.p1;
+    let d23 = c.p3 - c.p2;
+    let lp_lc = d01.hypot() + d12.hypot() + d23.hypot() - d03.hypot();
+    let dd1 = d12 - d01;
+    let dd2 = d23 - d12;
+    // It might be faster to do direct multiplies, the data dependencies would be shorter.
+    // The following values don't have the factor of 3 for first deriv
+    let dm = 0.25 * (d01 + d23) + 0.5 * d12; // first derivative at midpoint
+    let dm1 = 0.5 * (dd2 + dd1); // second derivative at midpoint
+    let dm2 = 0.25 * (dd2 - dd1); // 0.5 * (third derivative at midpoint)
+
+    let est = GAUSS_LEGENDRE_COEFFS_8
+        .iter()
+        .map(|&(wi, xi)| {
+            wi * {
+                let d_norm2 = (dm + dm1 * xi + dm2 * (xi * xi)).hypot2();
+                let dd_norm2 = (dm1 + dm2 * (2.0 * xi)).hypot2();
+                dd_norm2 / d_norm2
+            }
+        })
+        .sum::<f64>();
+    let est_gauss8_error = (est.powi(3) * 2.5e-6).min(3e-2) * lp_lc;
+    if est_gauss8_error < accuracy {
+        return arclen_quadrature_core(GAUSS_LEGENDRE_COEFFS_8_HALF, dm, dm1, dm2);
+    }
+    let est_gauss16_error = (est.powi(6) * 1.5e-11).min(9e-3) * lp_lc;
+    if est_gauss16_error < accuracy {
+        return arclen_quadrature_core(GAUSS_LEGENDRE_COEFFS_16_HALF, dm, dm1, dm2);
+    }
+    let est_gauss24_error = (est.powi(9) * 3.5e-16).min(3.5e-3) * lp_lc;
+    if est_gauss24_error < accuracy || depth >= 20 {
+        return arclen_quadrature_core(GAUSS_LEGENDRE_COEFFS_24_HALF, dm, dm1, dm2);
+    }
+    let (c0, c1) = c.subdivide();
+    arclen_rec(&c0, accuracy * 0.5, depth + 1) + arclen_rec(&c1, accuracy * 0.5, depth + 1)
+}
+
 impl ParamCurveArclen for CubicBez {
     /// Arclength of a cubic Bézier segment.
     ///
     /// This is an adaptive subdivision approach using Legendre-Gauss quadrature
     /// in the base case, and an error estimate to decide when to subdivide.
     fn arclen(&self, accuracy: f64) -> f64 {
-        // Squared L2 norm of the second derivative of the cubic.
-        fn cubic_errnorm(c: &CubicBez) -> f64 {
-            let d = c.deriv().deriv();
-            let dd = d.end() - d.start();
-            d.start().to_vec2().hypot2() + d.start().to_vec2().dot(dd) + dd.hypot2() * (1.0 / 3.0)
-        }
-        fn est_gauss9_error(c: &CubicBez) -> f64 {
-            let lc2 = (c.p3 - c.p0).hypot2();
-            let lp = (c.p1 - c.p0).hypot() + (c.p2 - c.p1).hypot() + (c.p3 - c.p2).hypot();
-
-            2.56e-8 * (cubic_errnorm(c) / lc2).powi(8) * lp
-        }
-        const MAX_DEPTH: usize = 16;
-        fn rec(c: &CubicBez, accuracy: f64, depth: usize) -> f64 {
-            if depth == MAX_DEPTH || est_gauss9_error(c) < accuracy {
-                c.gauss_arclen(GAUSS_LEGENDRE_COEFFS_9)
-            } else {
-                let (c0, c1) = c.subdivide();
-                rec(&c0, accuracy * 0.5, depth + 1) + rec(&c1, accuracy * 0.5, depth + 1)
-            }
-        }
-
-        // Check if the bezier curve is degenerate, or almost degenerate
-        // A degenerate curve where all points are identical will cause infinite recursion in the rec function (well, until MAX_DEPTH at least) in all branches.
-        // This test will in addition be true if the bezier curve is just a simple line (i.e. p0=p1 and p2=p3).
-        // The constant 0.5 has not been mathematically proven to be small enough, but from empirical tests
-        // a value of about 0.87 should be enough. Thus 0.5 is a conservative value.
-        // See https://github.com/linebender/kurbo/pull/100 for more info.
-        if (self.p1 - self.p0).hypot2() + (self.p2 - self.p3).hypot2() <= 0.5 * accuracy * accuracy
-        {
-            (self.p0 - self.p3).hypot()
-        } else {
-            rec(self, accuracy, 0)
-        }
+        arclen_rec(self, accuracy, 0)
     }
 }
 
@@ -548,6 +718,7 @@ impl Mul<CubicBez> for Affine {
 impl Iterator for ToQuads {
     type Item = (f64, f64, QuadBez);
 
+    #[inline]
     fn next(&mut self) -> Option<(f64, f64, QuadBez)> {
         if self.i == self.n {
             return None;
@@ -571,6 +742,8 @@ impl Iterator for ToQuads {
 /// Convert multiple cubic Bézier curves to quadratic splines.
 ///
 /// Ensures that the resulting splines have the same number of control points.
+///
+/// Rust port of cu2qu [cubic_approx_quadratic](https://github.com/fonttools/fonttools/blob/3b9a73ff8379ab49d3ce35aaaaf04b3a7d9d1655/Lib/fontTools/cu2qu/cu2qu.py#L322)
 pub fn cubics_to_quadratic_splines(curves: &[CubicBez], accuracy: f64) -> Option<Vec<QuadSpline>> {
     let mut result = Vec::new();
     let mut split_order = 0;
@@ -597,6 +770,7 @@ mod tests {
     use crate::{
         cubics_to_quadratic_splines, Affine, CubicBez, Nearest, ParamCurve, ParamCurveArclen,
         ParamCurveArea, ParamCurveDeriv, ParamCurveExtrema, ParamCurveNearest, Point, QuadBez,
+        QuadSpline,
     };
 
     #[test]
@@ -658,10 +832,7 @@ mod tests {
                 let actual_arc = c.subsegment(0.0..t).arclen(accuracy * 0.5);
                 assert!(
                     (arc - actual_arc).abs() < accuracy,
-                    "at accuracy {:e}, wanted {} got {}",
-                    accuracy,
-                    actual_arc,
-                    arc
+                    "at accuracy {accuracy:e}, wanted {actual_arc} got {arc}"
                 );
             }
         }
@@ -672,10 +843,7 @@ mod tests {
         let actual_arc = c.subsegment(0.0..t).arclen(accuracy);
         assert!(
             (arc - actual_arc).abs() < 2.0 * accuracy,
-            "at accuracy {:e}, want {} got {}",
-            accuracy,
-            actual_arc,
-            arc
+            "at accuracy {accuracy:e}, want {actual_arc} got {arc}"
         );
     }
 
@@ -723,9 +891,7 @@ mod tests {
         fn verify(result: Nearest, expected: f64) {
             assert!(
                 (result.t - expected).abs() < 1e-6,
-                "got {:?} expected {}",
-                result,
-                expected
+                "got {result:?} expected {expected}"
             );
         }
         // y = x^3
@@ -746,7 +912,7 @@ mod tests {
         verify((a * c).nearest(a * Point::new(0.1, 0.001), 1e-6), 0.1);
     }
 
-    // ensure to_quads returns something given colinear points
+    // ensure to_quads returns something given collinear points
     #[test]
     fn degenerate_to_quads() {
         let c = CubicBez::new((0., 9.), (6., 6.), (12., 3.0), (18., 0.0));
@@ -774,7 +940,7 @@ mod tests {
         for i in 0..10 {
             let accuracy = 0.1f64.powi(i);
             let mut worst: f64 = 0.0;
-            for (_count, (t0, t1, q)) in c.to_quads(accuracy).enumerate() {
+            for (t0, t1, q) in c.to_quads(accuracy) {
                 let epsilon = 1e-12;
                 assert!((q.start() - c.eval(t0)).hypot() < epsilon);
                 assert!((q.end() - c.eval(t1)).hypot() < epsilon);
@@ -784,7 +950,7 @@ mod tests {
                     let p = q.eval(t);
                     let err = (p.y - p.x.powi(3)).abs();
                     worst = worst.max(err);
-                    assert!(err < accuracy, "got {} wanted {}", err, accuracy);
+                    assert!(err < accuracy, "got {err} wanted {accuracy}");
                 }
             }
         }
@@ -814,7 +980,7 @@ mod tests {
         let spline = c1.approx_spline_n(2, 343.0);
         assert!(spline.is_some());
         let spline = spline.unwrap();
-        let expected = vec![
+        let expected = [
             Point::new(550.0, 258.0),
             Point::new(920.5, 426.0),
             Point::new(2005.25, 1769.25),
@@ -822,11 +988,11 @@ mod tests {
         ];
         assert_eq!(spline.points().len(), expected.len());
         for (got, &wanted) in spline.points().iter().zip(expected.iter()) {
-            assert!(got.distance(wanted) < 5.0)
+            assert!(got.distance(wanted) < 5.0);
         }
 
         let spline = c1.approx_spline(5.0);
-        let expected = vec![
+        let expected = [
             Point::new(550.0, 258.0),
             Point::new(673.5, 314.0),
             Point::new(984.8777777777776, 584.2666666666667),
@@ -840,7 +1006,7 @@ mod tests {
         let spline = spline.unwrap();
         assert_eq!(spline.points().len(), expected.len());
         for (got, &wanted) in spline.points().iter().zip(expected.iter()) {
-            assert!(got.distance(wanted) < 5.0)
+            assert!(got.distance(wanted) < 5.0);
         }
     }
 
@@ -877,4 +1043,136 @@ mod tests {
             converted[0].points()[2].distance(Point::new(88639.0 / 90.0, 52584.0 / 90.0)) < 0.0001
         );
     }
+
+    #[test]
+    fn cubicbez_approx_spline_div_exact() {
+        // Ensure rounding behavior for division matches fonttools
+        // cu2qu.
+        // See <https://github.com/linebender/kurbo/issues/272>
+        let cubic = CubicBez::new(
+            Point::new(408.0, 321.0),
+            Point::new(408.0, 452.0),
+            Point::new(342.0, 560.0),
+            Point::new(260.0, 560.0),
+        );
+        let spline = cubic.approx_spline(1.0).unwrap();
+        assert_eq!(
+            spline.points(),
+            &[
+                Point::new(408.0, 321.0),
+                // Previous behavior produced 386.49999999999994 for the
+                // y coordinate leading to inconsistent rounding.
+                Point::new(408.0, 386.5),
+                Point::new(368.16666666666663, 495.0833333333333),
+                Point::new(301.0, 560.0),
+                Point::new(260.0, 560.0)
+            ]
+        );
+    }
+
+    #[test]
+    fn cubicbez_inflections() {
+        let c = CubicBez::new((0., 0.), (0.8, 1.), (0.2, 1.), (1., 0.));
+        let inflections = c.inflections();
+        assert_eq!(inflections.len(), 2);
+        assert!((inflections[0] - 0.311018).abs() < 1e-6);
+        assert!((inflections[1] - 0.688982).abs() < 1e-6);
+        let c = CubicBez::new((0., 0.), (1., 1.), (2., -1.), (3., 0.));
+        let inflections = c.inflections();
+        assert_eq!(inflections.len(), 1);
+        assert!((inflections[0] - 0.5).abs() < 1e-6);
+        let c = CubicBez::new((0., 0.), (1., 1.), (2., 1.), (3., 0.));
+        let inflections = c.inflections();
+        assert_eq!(inflections.len(), 0);
+    }
+
+    #[test]
+    fn cubic_to_quadratic_matches_python() {
+        // from https://github.com/googlefonts/fontmake-rs/issues/217
+        let cubic = CubicBez {
+            p0: (796.0, 319.0).into(),
+            p1: (727.0, 314.0).into(),
+            p2: (242.0, 303.0).into(),
+            p3: (106.0, 303.0).into(),
+        };
+
+        // FontTools can approximate this curve successfully in 7 splits, we can too
+        assert!(cubic.approx_spline_n(7, 1.0).is_some());
+
+        // FontTools can solve this with accuracy 0.001, we can too
+        assert!(cubics_to_quadratic_splines(&[cubic], 0.001).is_some());
+    }
+
+    #[test]
+    fn cubic_to_quadratic_all_points_equal() {
+        let pt = Point::new(5.0, 5.0);
+        let cubic = CubicBez::new(pt, pt, pt, pt);
+        let quads = cubics_to_quadratic_splines(&[cubic], 0.1).unwrap();
+        assert_eq!(quads, [QuadSpline::new(vec![pt, pt, pt])]);
+    }
+
+    #[test]
+    fn cubic_to_quadratic_3_points_equal_single_quad_within_tolerance() {
+        let p0 = Point::new(5.0, 5.0);
+        let p1 = Point::new(5.0, 5.1);
+        let cubic = CubicBez::new(p0, p0, p0, p1);
+        let quads = cubics_to_quadratic_splines(&[cubic], 0.1).unwrap();
+        // a single quadratic bezier approximates this cubic for the given tolerance
+        assert_eq!(quads, [QuadSpline::new(vec![p0, p0, p1])]);
+    }
+
+    #[test]
+    fn cubic_to_quadratic_3_points_equal_exceeding_tolerance() {
+        let p0 = Point::new(5.0, 5.0);
+        let p1 = Point::new(5.0, 5.1);
+        let cubic = CubicBez::new(p0, p0, p0, p1);
+        let quads = cubics_to_quadratic_splines(&[cubic], 0.01).unwrap();
+        // 2 quadratic off-curves are required to approximate the same cubic
+        // given the smaller tolerance
+        assert_eq!(
+            quads,
+            [QuadSpline::new(vec![p0, p0, (5.0, 5.025).into(), p1])]
+        );
+    }
+
+    #[test]
+    fn cubics_to_quadratic_splines_matches_python() {
+        // https://github.com/linebender/kurbo/pull/273
+        let light = CubicBez::new((378., 608.), (378., 524.), (355., 455.), (266., 455.));
+        let regular = CubicBez::new((367., 607.), (367., 511.), (338., 472.), (243., 472.));
+        let bold = CubicBez::new(
+            (372.425, 593.05),
+            (372.425, 524.95),
+            (355.05, 485.95),
+            (274., 485.95),
+        );
+        let qsplines = cubics_to_quadratic_splines(&[light, regular, bold], 1.0).unwrap();
+        assert_eq!(
+            qsplines,
+            [
+                QuadSpline::new(vec![
+                    (378.0, 608.0).into(),
+                    (378.0, 566.0).into(),
+                    (359.0833333333333, 496.5).into(),
+                    (310.5, 455.0).into(),
+                    (266.0, 455.0).into(),
+                ]),
+                QuadSpline::new(vec![
+                    (367.0, 607.0).into(),
+                    (367.0, 559.0).into(),
+                    // Previous behavior produced 496.5 for the y coordinate
+                    (344.5833333333333, 499.49999999999994).into(),
+                    (290.5, 472.0).into(),
+                    (243.0, 472.0).into(),
+                ]),
+                QuadSpline::new(vec![
+                    (372.425, 593.05).into(),
+                    (372.425, 559.0).into(),
+                    (356.98333333333335, 511.125).into(),
+                    (314.525, 485.95).into(),
+                    (274.0, 485.95).into(),
+                ]),
+            ]
+        );
+    }
 }
