@@ -1,3 +1,6 @@
+// Copyright 2021 the SVG Types Authors
+// SPDX-License-Identifier: Apache-2.0 OR MIT
+
 use crate::{Angle, AngleUnit, Color, Error, Length, LengthUnit, Stream};
 
 /// Representation of the [`<filter-function>`] | [`<url>`] type.
@@ -66,40 +69,39 @@ pub enum FilterValueListParserError {
 
 impl From<Error> for FilterValueListParserError {
     fn from(e: Error) -> Self {
-        FilterValueListParserError::StreamErrors(e)
+        Self::StreamErrors(e)
     }
 }
 
-impl std::fmt::Display for FilterValueListParserError {
-    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+impl core::fmt::Display for FilterValueListParserError {
+    fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
         match *self {
-            FilterValueListParserError::PercentageValue(pos) => {
-                write!(f, "a percentage value detected at position {}", pos)
+            Self::PercentageValue(pos) => {
+                write!(f, "a percentage value detected at position {pos}")
             }
-            FilterValueListParserError::NegativeValue(pos) => {
-                write!(f, "a negative value detected at position {}", pos)
+            Self::NegativeValue(pos) => {
+                write!(f, "a negative value detected at position {pos}")
             }
-            FilterValueListParserError::InvalidAngle(pos) => {
-                write!(f, "an invalid angle at position {}", pos)
+            Self::InvalidAngle(pos) => {
+                write!(f, "an invalid angle at position {pos}")
             }
-            FilterValueListParserError::MissingDropShadowOffset(pos) => {
+            Self::MissingDropShadowOffset(pos) => {
                 write!(
                     f,
-                    "drop-shadow offset values are expected at position {}",
-                    pos
+                    "drop-shadow offset values are expected at position {pos}"
                 )
             }
-            FilterValueListParserError::InvalidUrl(pos) => {
-                write!(f, "an invalid url at position {}", pos)
+            Self::InvalidUrl(pos) => {
+                write!(f, "an invalid url at position {pos}")
             }
-            FilterValueListParserError::StreamErrors(ref e) => {
-                write!(f, "{}", e)
+            Self::StreamErrors(ref e) => {
+                write!(f, "{e}")
             }
         }
     }
 }
 
-impl std::error::Error for FilterValueListParserError {
+impl core::error::Error for FilterValueListParserError {
     fn description(&self) -> &str {
         "filter-value-list parsing error"
     }
@@ -161,7 +163,7 @@ impl<'a> FilterValueListParser<'a> {
         let s = &mut self.stream;
 
         let start = s.pos();
-        let name = s.consume_ident();
+        let name = s.consume_ascii_ident();
         s.skip_spaces();
         s.consume_byte(b'(')?;
         s.skip_spaces();
@@ -268,7 +270,7 @@ fn parse_drop_shadow_func<'a>(
 }
 
 #[inline(never)]
-fn parse_generic_color_func(s: &mut Stream) -> Result<f64, FilterValueListParserError> {
+fn parse_generic_color_func(s: &mut Stream<'_>) -> Result<f64, FilterValueListParserError> {
     if s.is_curr_byte_eq(b')') {
         Ok(1.0)
     } else {
@@ -284,7 +286,7 @@ fn parse_generic_color_func(s: &mut Stream) -> Result<f64, FilterValueListParser
     }
 }
 
-fn parse_filter_length(s: &mut Stream) -> Result<Length, FilterValueListParserError> {
+fn parse_filter_length(s: &mut Stream<'_>) -> Result<Length, FilterValueListParserError> {
     let start = s.pos();
     let value = s.parse_length()?;
 
@@ -296,7 +298,7 @@ fn parse_filter_length(s: &mut Stream) -> Result<Length, FilterValueListParserEr
     Ok(value)
 }
 
-fn parse_filter_positive_length(s: &mut Stream) -> Result<Length, FilterValueListParserError> {
+fn parse_filter_positive_length(s: &mut Stream<'_>) -> Result<Length, FilterValueListParserError> {
     let start = s.pos();
     let value = s.parse_length()?;
 
@@ -314,7 +316,7 @@ fn parse_filter_positive_length(s: &mut Stream) -> Result<Length, FilterValueLis
 }
 
 // Just like a normal angle, but units are mandatory.
-fn parse_filter_angle(s: &mut Stream) -> Result<Angle, FilterValueListParserError> {
+fn parse_filter_angle(s: &mut Stream<'_>) -> Result<Angle, FilterValueListParserError> {
     s.skip_spaces();
 
     let start = s.pos();
@@ -349,6 +351,7 @@ fn parse_filter_angle(s: &mut Stream) -> Result<Angle, FilterValueListParserErro
 #[cfg(test)]
 mod tests {
     use super::*;
+    use alloc::string::ToString;
     use crate::Color;
 
     #[test]
