@@ -1,8 +1,12 @@
+// Copyright 2021 the SVG Types Authors
+// SPDX-License-Identifier: Apache-2.0 OR MIT
+
 use crate::{Error, Stream};
+use alloc::vec::Vec;
 
 /// Representation of a path segment.
 ///
-/// If you want to change the segment type (for example MoveTo to LineTo)
+/// If you want to change the segment type (for example `MoveTo` to `LineTo`)
 /// you should create a new segment.
 /// But you still can change points or make segment relative or absolute.
 #[allow(missing_docs)]
@@ -69,6 +73,88 @@ pub enum PathSegment {
     },
 }
 
+impl PathSegment {
+    /// Returns `true` if the segment is absolute.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use svgtypes::{PathParser, PathSegment};
+    ///
+    /// let mut segments = Vec::new();
+    /// for segment in PathParser::from("M10-20l30.1.5.1-20z") {
+    ///     segments.push(segment.unwrap());
+    /// }
+    ///
+    /// assert_eq!(segments[0].is_abs(), true);
+    /// assert_eq!(segments[1].is_abs(), false);
+    /// assert_eq!(segments[2].is_abs(), false);
+    /// assert_eq!(segments[3].is_abs(), false);
+    /// ```
+    ///
+    pub fn is_abs(&self) -> bool {
+        match *self {
+            Self::MoveTo { abs, .. } => abs,
+            Self::LineTo { abs, .. } => abs,
+            Self::HorizontalLineTo { abs, .. } => abs,
+            Self::VerticalLineTo { abs, .. } => abs,
+            Self::CurveTo { abs, .. } => abs,
+            Self::SmoothCurveTo { abs, .. } => abs,
+            Self::Quadratic { abs, .. } => abs,
+            Self::SmoothQuadratic { abs, .. } => abs,
+            Self::EllipticalArc { abs, .. } => abs,
+            Self::ClosePath { abs } => abs,
+        }
+    }
+
+    /// Returns the segment letter.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use svgtypes::{PathParser, PathSegment};
+    ///
+    /// let mut segments = Vec::new();
+    /// for segment in PathParser::from("M10-20l30.1.5.1-20z") {
+    ///     segments.push(segment.unwrap());
+    /// }
+    ///
+    /// assert_eq!(segments[0].command(), b'M');
+    /// assert_eq!(segments[1].command(), b'l');
+    /// assert_eq!(segments[2].command(), b'l');
+    /// assert_eq!(segments[3].command(), b'z');
+    /// ```
+    ///
+    pub fn command(&self) -> u8 {
+        match self.is_abs() {
+            true => match *self {
+                Self::MoveTo { .. } => b'M',
+                Self::LineTo { .. } => b'L',
+                Self::HorizontalLineTo { .. } => b'H',
+                Self::VerticalLineTo { .. } => b'V',
+                Self::CurveTo { .. } => b'C',
+                Self::SmoothCurveTo { .. } => b'S',
+                Self::Quadratic { .. } => b'Q',
+                Self::SmoothQuadratic { .. } => b'T',
+                Self::EllipticalArc { .. } => b'A',
+                Self::ClosePath { .. } => b'Z',
+            },
+            false => match *self {
+                Self::MoveTo { .. } => b'm',
+                Self::LineTo { .. } => b'l',
+                Self::HorizontalLineTo { .. } => b'h',
+                Self::VerticalLineTo { .. } => b'v',
+                Self::CurveTo { .. } => b'c',
+                Self::SmoothCurveTo { .. } => b's',
+                Self::Quadratic { .. } => b'q',
+                Self::SmoothQuadratic { .. } => b't',
+                Self::EllipticalArc { .. } => b'a',
+                Self::ClosePath { .. } => b'z',
+            },
+        }
+    }
+}
+
 /// A pull-based [path data] parser.
 ///
 /// # Errors
@@ -78,8 +164,8 @@ pub enum PathSegment {
 /// # Notes
 ///
 /// The library does not support implicit commands, so they will be converted to an explicit one.
-/// It mostly affects an implicit MoveTo, which will be converted, according to the spec,
-/// into explicit LineTo.
+/// It mostly affects an implicit `MoveTo`, which will be converted, according to the spec,
+/// into an explicit `LineTo`.
 ///
 /// Example: `M 10 20 30 40 50 60` -> `M 10 20 L 30 40 L 50 60`
 ///
@@ -118,7 +204,7 @@ impl<'a> From<&'a str> for PathParser<'a> {
     }
 }
 
-impl<'a> Iterator for PathParser<'a> {
+impl Iterator for PathParser<'_> {
     type Item = Result<PathSegment, Error>;
 
     #[inline]
@@ -140,7 +226,7 @@ impl<'a> Iterator for PathParser<'a> {
     }
 }
 
-fn next_impl(s: &mut Stream, prev_cmd: &mut Option<u8>) -> Result<PathSegment, Error> {
+fn next_impl(s: &mut Stream<'_>, prev_cmd: &mut Option<u8>) -> Result<PathSegment, Error> {
     let start = s.pos();
 
     let has_prev_cmd = prev_cmd.is_some();
@@ -252,11 +338,7 @@ fn next_impl(s: &mut Stream, prev_cmd: &mut Option<u8>) -> Result<PathSegment, E
     };
 
     *prev_cmd = Some(if is_implicit_move_to {
-        if absolute {
-            b'M'
-        } else {
-            b'm'
-        }
+        if absolute { b'M' } else { b'm' }
     } else {
         cmd
     });
@@ -317,7 +399,7 @@ fn is_number_start(c: u8) -> bool {
 
 // By the SVG spec 'large-arc' and 'sweep' must contain only one char
 // and can be written without any separators, e.g.: 10 20 30 01 10 20.
-fn parse_flag(s: &mut Stream) -> Result<bool, Error> {
+fn parse_flag(s: &mut Stream<'_>) -> Result<bool, Error> {
     s.skip_spaces();
 
     let c = s.curr_byte()?;
@@ -571,6 +653,13 @@ mod tests {
         PathSegment::ClosePath { abs: true },
         PathSegment::HorizontalLineTo { abs: true, x: 10.0 }
     );
+
+    #[test]
+    fn test_helper_functions(){
+        assert!(PathSegment::MoveTo { abs: true, x: 0.0, y: 0.0 }.is_abs());
+        assert!(!PathSegment::MoveTo { abs: false, x: 0.0, y: 0.0 }.is_abs()); // asserting false
+        assert_eq!(PathSegment::MoveTo { abs: true, x: 0.0, y: 0.0 }.command(), b'M');
+    }
 }
 
 /// Representation of a simple path segment.
@@ -607,11 +696,12 @@ pub enum SimplePathSegment {
 /// A more high-level Path Data parser on top of [`PathParser`] that provides:
 ///
 /// - Relative to absolute segment coordinates conversion
-/// - ArcTo to CurveTos conversion
-/// - SmoothCurveTo and SmoothQuadratic conversion
-/// - HorizontalLineTo and VerticalLineTo to LineTo conversion
+/// - `ArcTo` to `CurveTo`s conversion
+/// - `SmoothCurveTo` and `SmoothQuadratic` conversion
+/// - `HorizontalLineTo` and `VerticalLineTo` to `LineTo` conversion
+/// - Implicit `MoveTo` after `ClosePath` handling
 ///
-/// In the end, only absolute MoveTo, LineTo, CurveTo, Quadratic and ClosePath segments
+/// In the end, only absolute `MoveTo`, `LineTo`, `CurveTo`, `Quadratic` and `ClosePath` segments
 /// will be produced.
 #[derive(Clone, Debug)]
 pub struct SimplifyingPathParser<'a> {
@@ -657,10 +747,9 @@ impl<'a> From<&'a str> for SimplifyingPathParser<'a> {
     }
 }
 
-impl<'a> Iterator for SimplifyingPathParser<'a> {
+impl Iterator for SimplifyingPathParser<'_> {
     type Item = Result<SimplePathSegment, Error>;
 
-    #[inline]
     fn next(&mut self) -> Option<Self::Item> {
         if !self.buffer.is_empty() {
             return Some(Ok(self.buffer.remove(0)));
@@ -671,6 +760,22 @@ impl<'a> Iterator for SimplifyingPathParser<'a> {
             Err(e) => return Some(Err(e)),
         };
 
+        // If a ClosePath segment is followed by any command other than MoveTo or ClosePath
+        // then MoveTo is implicit.
+        if let Some(SimplePathSegment::ClosePath) = self.prev_simple_seg {
+            match segment {
+                PathSegment::MoveTo { .. } | PathSegment::ClosePath { .. } => {}
+                _ => {
+                    let new_seg = SimplePathSegment::MoveTo {
+                        x: self.prev_mx,
+                        y: self.prev_my,
+                    };
+                    self.buffer.push(new_seg);
+                    self.prev_simple_seg = Some(new_seg);
+                }
+            }
+        }
+
         match segment {
             PathSegment::MoveTo { abs, mut x, mut y } => {
                 if !abs {
@@ -899,7 +1004,7 @@ impl<'a> Iterator for SimplifyingPathParser<'a> {
             PathSegment::ClosePath { .. } => {
                 if let Some(SimplePathSegment::ClosePath) = self.prev_simple_seg {
                     // Do not add sequential ClosePath segments.
-                    // Otherwise it will break marker rendering.
+                    // Otherwise it will break markers rendering.
                 } else {
                     self.buffer.push(SimplePathSegment::ClosePath);
                 }
@@ -932,8 +1037,7 @@ impl<'a> Iterator for SimplifyingPathParser<'a> {
                     self.prev_y = y;
                 }
                 SimplePathSegment::ClosePath => {
-                    // ClosePath moves us to the last MoveTo coordinate,
-                    // not previous.
+                    // ClosePath moves us to the last MoveTo coordinate.
                     self.prev_x = self.prev_mx;
                     self.prev_y = self.prev_my;
                 }
@@ -992,6 +1096,20 @@ mod simple_tests {
         SimplePathSegment::CurveTo { x1: 29.0, y1: 135.0, x2: 171.0, y2: 45.0, x: 180.0, y: 155.0 }
     );
 
+    test!(relative_smooth_curve_to_after_arc_to, "M 1 5 A 5 5 0 0 1 3 1 s 3 2 8 2",
+        SimplePathSegment::MoveTo { x: 1.0, y: 5.0 },
+        SimplePathSegment::CurveTo {
+            x1: 1.0, y1: 3.4262134833347355,
+            x2: 1.7409707866677877, y2: 1.9442719099991592,
+            x: 2.9999999999999996, y: 1.0000000000000004
+        },
+        SimplePathSegment::CurveTo {
+            x1: 2.9999999999999996, y1: 1.0000000000000004,
+            x2: 6.0, y2: 3.0000000000000004,
+            x: 11.0, y: 3.0000000000000004
+        }
+    );
+
     test!(smooth_quadratic_after_move_to, "M 30 40 T 180 155",
         SimplePathSegment::MoveTo { x: 30.0, y: 40.0 },
         SimplePathSegment::Quadratic { x1: 30.0, y1: 40.0, x: 180.0, y: 155.0 }
@@ -1045,6 +1163,27 @@ mod simple_tests {
         SimplePathSegment::Quadratic { x1: 80.0, y1: 180.0, x: 170.0, y: 30.0 }
     );
 
+    test!(relative_smooth_quadratic_to_after_arc_to, "M 1 5 A 5 5 0 0 1 3 1 t 8 2",
+        SimplePathSegment::MoveTo { x: 1.0, y: 5.0 },
+        SimplePathSegment::CurveTo {
+            x1: 1.0, y1: 3.4262134833347355,
+            x2: 1.7409707866677877, y2: 1.9442719099991592,
+            x: 2.9999999999999996, y: 1.0000000000000004
+        },
+        SimplePathSegment::Quadratic {
+            x1: 2.9999999999999996, y1: 1.0000000000000004,
+            x: 11.0, y: 3.0000000000000004
+        }
+    );
+
+    test!(implicit_move_to_after_close_path, "M 10 20 L 30 40 Z L 50 60",
+        SimplePathSegment::MoveTo { x: 10.0, y: 20.0 },
+        SimplePathSegment::LineTo { x: 30.0, y: 40.0 },
+        SimplePathSegment::ClosePath,
+        SimplePathSegment::MoveTo { x: 10.0, y: 20.0 },
+        SimplePathSegment::LineTo { x: 50.0, y: 60.0 }
+    );
+
     #[test]
     fn arc_to() {
         let mut s = SimplifyingPathParser::from("M 30 40 A 40 30 20 1 1 150 100");
